NPTCRescaleState

class torch_sim.integrators.npt.NPTCRescaleState(*, positions, masses, cell, pbc, atomic_numbers, system_idx=None, _constraints=<factory>, _system_extras=<factory>, _atom_extras=<factory>, _rng=None, momenta, energy, forces, stress, isothermal_compressibility, tau_p, initial_cell, initial_cell_inv, initial_volume)[source]

Bases: NPTState

State for NPT ensemble with cell rescaling barostat.

This class extends the NPTState to include variables and properties specific to the NPT ensemble with a cell rescaling barostat.

Parameters:
get_number_of_degrees_of_freedom()[source]

Calculate degrees of freedom for each system in the batch.

Returns:

Degrees of freedom for each system, shape [n_systems]

Return type:

Tensor