torch_sim.mathΒΆ

Mathematical operations and utilities. Adapted from https://github.com/abhijeetgangan/torch_matfunc.

Functions

batched_vdot

Computes batched vdot (sum of element-wise product) for groups of vectors.

expm_frechet

Frechet derivative of the matrix exponential of A in the direction E.

expm_frechet_block_enlarge

Block-enlarge helper for Frechet derivative via matrix exponential.

expm_frechet_sps

Scaling-Pade-squaring helper for Frechet derivative of exp(A) on 3x3 matrices.

matrix_exp

Compute the matrix exponential of A using PyTorch's matrix_exp.

matrix_log_33

Compute the matrix logarithm of a square 3x3 matrix.

matrix_log_scipy

Compute the matrix logarithm of a square matrix using scipy.linalg.logm.

Classes

ell_table_61

Built-in immutable sequence.