SoftSphereModel

class torch_sim.models.soft_sphere.SoftSphereModel(sigma=1.0, epsilon=1.0, alpha=2.0, device=None, dtype=torch.float64, *, compute_forces=True, compute_stress=False, per_atom_energies=False, per_atom_stresses=False, neighbor_list_fn=torchsim_nl, use_neighbor_list=True, cutoff=None, retain_graph=False)[source]

Bases: PairPotentialModel

Soft-sphere repulsive pair potential model.

Convenience subclass that fixes the pair function to soft_sphere_pair() so the caller only needs to supply sigma, epsilon, and alpha.

Example:

model = SoftSphereModel(
    sigma=3.405,
    epsilon=0.0104,
    alpha=2.0,
    compute_forces=True,
)
results = model(sim_state)
Parameters: