torch_sim.stateΒΆ

The core state representation.

The main SimState class represents atomistic systems with support for batched operations and conversion to/from various atomistic formats.

Functions

coerce_prng

Coerce an int seed or existing Generator into a torch.Generator.

concatenate_states

Concatenate a list of SimStates into a single SimState.

get_attrs_for_scope

Get attributes for a given scope.

initialize_state

Initialize state tensors from a atomistic system representation.

require_system_idx

Return non-null system indices or raise with a clear invariant message.

Classes

DeformGradMixin

Mixin for states that support deformation gradients.

SimState

State representation for atomistic systems with batched operations support.

TYPE_CHECKING

bool(x) -> bool