DEFAULT_OOM_ERROR_MESSAGES¶
- torch_sim.autobatching.DEFAULT_OOM_ERROR_MESSAGES = ('CUDA out of memory', 'Failed to allocate')¶
Built-in immutable sequence.
If no argument is given, the constructor returns an empty tuple. If iterable is specified the tuple is initialized from iterable’s items.
If the argument is a tuple, the return value is the same object.