torch_sim.models.polarizationΒΆ
Electric-field corrections for polarization-aware models.
Classes
Calculates the energy and force contributions from the application of a constant electric field to a polarizable system. |
Electric-field corrections for polarization-aware models.
Classes
Calculates the energy and force contributions from the application of a constant electric field to a polarizable system. |